#!/bin/bash

# sqp_JogglerFeatures.sh v1.17 (17th September 2014) by Andy Davison
#  Executed by JogglerFeatures applet on SQPOS.

export PATH=$PATH:`dirname $0`
[ ! -e ~/.squeezeplay ] && mkdir ~/.squeezeplay

DEBUG=0

sudo ntpdate ntp2d.mcc.ac.uk &>/dev/null &

if [ "$1" = "freespace" ]; then
	DFOUT=`df -h /`
	INSINT=`echo "$DFOUT" | grep -c mmcblk0`
	echo
	[ "$INSINT" == 0 ] && echo "Installed to an external storage device."
	[ "$INSINT" != 0 ] && echo "Installed to internal memory."
	echo
	echo "$DFOUT"
	exit 0
fi

if [ "$1" = "freeraw" ]; then
	df -k / | grep / | awk -F\  {'print $4'}
	exit 0
fi


#### AirPlay

if [ "$1" = "air" ]; then
	
	if [ "$2" = "install" ]; then

		wget http://birdslikewires.co.uk/download/joggler/squeezeplay/os/additional/shairport_sqpos.tgz -O /tmp/shairport_sqpos.tgz  &> ~/.squeezeplay/additional.log
		tar zxvf /tmp/shairport_sqpos.tgz -C /tmp/  &> ~/.squeezeplay/additional.log
		sudo mv /tmp/shairport_sqpos/shairport /usr/local/bin/shairport  &> ~/.squeezeplay/additional.log
		sudo dpkg -i /tmp/shairport_sqpos/deps/* &> ~/.squeezeplay/additional.log
		$0 air enable		

	fi

	## Don't forget: this start/stop routine is also used by squeezeplay.sh at startup.

	if [ "$2" = "enable" ] || [ "$2" = "start" ]; then

		# If we're starting up, check that we actually want to include AirPlay
		if [ "$2" = "start" ]; then
			AIRSTATUS=`cat ~/.squeezeplay/userpath/settings/JogglerFeatures.lua | awk -F\air=\" {'print $2'} | awk -F\" {'print $1'}`
			[ "$AIRSTATUS" = "enabled" ] || exit 0
		fi
	
		# Then we can get on with the business of starting properly.
		$0 air stop
		SQPNAME=`cat ~/.squeezeplay/userpath/settings/Playback.lua | awk -F\name=\" {'print $2'} | awk -F\" {'print $1'}`
		[ $SQPNAME = "" ] && SQPNAME="Unnamed SqueezePlay"
		/usr/local/bin/shairport -a "$SQPNAME" -b 271 -d -q

	fi
	
	if [ "$2" = "disable" ] || [ "$2" = "stop" ]; then

		killall shairport
		sudo service avahi-daemon restart
		sleep 1

	fi
	
	exit 0

fi


#### Logitech Media Server

if [ "$1" = "lms" ]; then

	LMSSERVER="http://downloads.slimdevices.com"
	LMSVERSION="7.8.0"

	if [ "$2" == "help" ]; then
		IP=`sqp_JogglerNetwork.sh ip | awk -F\:\  '{print $2}'`
		echo -n "Logitech Media Server allows you to serve content from this device. After installation, visit http://$IP:9000 with your browser to configure the server software."
		exit 0
	fi

	if [ "$2" = "install" ]; then
		
		wget -P /tmp $LMSSERVER"/LogitechMediaServer_v"$LMSVERSION"/logitechmediaserver_"$LMSVERSION"_all.deb"
		sudo dpkg -i /tmp/logitechmediaserver_"$LMSVERSION"_all.deb &> ~/.squeezeplay/additional.log
		# Strip other architectures
		sleep 2
		find /usr/share/squeezeboxserver/CPAN/arch -maxdepth 2 ! -iname 'i386*' -and -iname '*linux*' -exec sudo rm -rf '{}' \;
		sleep 2
		rm /tmp/logitechmediaserver_"$LMSVERSION"_all.deb
		#[ $DEBUG -ne 1 ] && sudo reboot		
		exit 0
	
	fi

	if [ "$2" = "uninstall" ]; then
	
		sudo dpkg --purge logitechmediaserver &> ~/.squeezeplay/additional.log
		sudo rm -rf /var/lib/squeezeboxserver
		sleep 2
		#[ $DEBUG -ne 1 ] && sudo reboot		
		exit 0
	
	fi

fi


#### Network Mount Point

if [ "$1" = "nmp" ]; then

	[ ! -d /srv/media ] && sudo mkdir /srv/media

	NMPOPTIONS=`cat ~/.squeezeplay/userpath/settings/JogglerFeatures.lua`
	NMPPROTO=`echo $NMPOPTIONS | awk -F\nmp=\" {'print $2'} | awk -F\" {'print $1'}`
	NMPIP=`echo $NMPOPTIONS | awk -F\nmpip={s=\" {'print $2'} | awk -F\" {'print $1'}`
	NMPPATH=`echo $NMPOPTIONS | awk -F\nmppath={s=\" {'print $2'} | awk -F\" {'print $1'} | sed 's/ /\\\040/g'`
	NMPFSTAB=`cat /etc/fstab | grep -c "/srv/media"`

	if [ "$NMPPROTO" = "disabled" ]; then
		
		if [ "$NMPFSTAB" = 1 ]; then
			echo "Network Mount Point disabled; unmounting and removing fstab config."
			sudo umount -f /srv/media 2>/dev/null
			cat /etc/fstab | grep -v "/srv/media" > /tmp/fstab.tmp
			sudo mv /tmp/fstab.tmp /etc/fstab
		else
			echo "Network Mount Point disabled and no fstab configuration is present."
		fi
		exit 0
	
	else	
	
		if [ -n "$NMPPROTO" ] && [ -n "$NMPIP" ] && [ -n "$NMPPATH" ]; then
		
			cp /etc/fstab /tmp/fstab.tmp
		
			if [ "$NMPPROTO" = "nfs" ]; then
			
				echo "Network Mount Point enabled for NFS; configuring and mounting."
				echo "$NMPIP:$NMPPATH   /srv/media   nfs   defaults,user,auto,noatime,intr   0 0" >> /tmp/fstab.tmp
			
			fi

			if [ "$NMPPROTO" = "smb" ]; then
				
				NMPSMBUSER=`echo $NMPOPTIONS | awk -F\nmpsmbuser=\{s= {'print $2'} | awk -F\" {'print $2'}`
				NMPSMBPASS=`echo $NMPOPTIONS | awk -F\nmpsmbpass=\{s= {'print $2'} | awk -F\" {'print $2'}`
				
				if [ -n "$NMPSMBUSER" ] && [ -n "$NMPSMBPASS" ]; then
					echo "Network Mount Point enabled for SMB; configuring and mounting."
					echo "//$NMPIP/$NMPPATH   /srv/media   cifs   username=$NMPSMBUSER,password=$NMPSMBPASS,_netdev   0 0" >> /tmp/fstab.tmp
				else
					echo "Network Mount Point cannot continue; no username or password specified."
					exit 1
				fi
			
			fi

			sudo mv /tmp/fstab.tmp /etc/fstab
			sleep 1
			sudo mount /srv/media
		
		else

			echo "Network Mount Point cannot continue; we need both the IP and path to do anything useful!"

		fi
		
		exit 0
	
	fi

fi


#### SSH

if [ "$1" = "ssh" ]; then

	if [ "$2" = "install" ]; then
		
		sudo dpkg -i /opt/squeezeplay/config/sqpos/packages/ssh/* &> ~/.squeezeplay/additional.log
		exit 0
	
	fi

	if [ "$2" = "uninstall" ]; then
	
		sudo dpkg --purge ssh openssh-server &> ~/.squeezeplay/additional.log
		sleep 2
		[ $DEBUG -ne 1 ] && sudo reboot		
		exit 0
	
	fi

fi


#### SSH Start / Stop (for v2.01 and later where SSH is preinstalled)

if [ "$1" = "sshss" ]; then

	if [ "$2" = "disable" ]; then
		
		sudo touch /etc/ssh/sshd_not_to_be_run
		sync
		sudo service ssh stop
		exit 0
	
	fi

	if [ "$2" = "enable" ]; then
	
		sudo rm /etc/ssh/sshd_not_to_be_run
		sync
		sudo service ssh start
		exit 0
	
	fi

fi



